@@ -7,6 +7,7 @@
 #include "utils.h"
 
 #include <DNotifySender>
+#include <DGuiApplicationHelper>
 
 #include <signal.h>
 #include <QStandardPaths>
@@ -530,10 +531,14 @@ void CommonInfoWork::setUeProgram(bool enabled)
         auto pathType = "-c";
         if (!SYSTEM_LOCAL_LIST.contains(QLocale::system().name()))
             pathType = "-e";
+        
+        auto themeType = Dtk::Gui::DGuiApplicationHelper::instance()->themeType();
+        QString theme = themeType == Dtk::Gui::DGuiApplicationHelper::DarkType ? "dark" : "light";
+        
         m_process->start("dde-license-dialog",
-                                      QStringList() << "-t" << m_title << pathType << m_content << "-a" << allowContent);
+                                      QStringList() << "-t" << m_title << pathType << m_content << "-a" << allowContent << "-p" << theme);
         qDebug()<<" Deliver content QStringList() = "<<"dde-license-dialog"
-                                                     << "-t" << m_title << pathType << m_content << "-a" << allowContent;
+                                                     << "-t" << m_title << pathType << m_content << "-a" << allowContent << "-p" << theme;
         connect(m_process, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, [=](int result) {
             if (96 == result) {
                 m_commonInfoProxy->Enable(enabled);
@@ -591,8 +596,11 @@ void CommonInfoWork::setEnableDeveloperMode(bool enabled)
     if (!sl.contains(QLocale::system().name()))
         pathType = "-e";
 
+    auto themeType = Dtk::Gui::DGuiApplicationHelper::instance()->themeType();
+    QString theme = themeType == Dtk::Gui::DGuiApplicationHelper::DarkType ? "dark" : "light";
+
     m_process = new QProcess(this);
-    m_process->start("dde-license-dialog", QStringList() << "-t" << title << pathType << contentPath << "-a" << allowContent);
+    m_process->start("dde-license-dialog", QStringList() << "-t" << title << pathType << contentPath << "-a" << allowContent << "-p" << theme);
 
     connect(m_process, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, [=](int result) {
         if (96 == result) {
